function Clips=DelineateSoundClip(Clip, Fs, MinFundFreq, MinSepSecs, varargin)

p=inputParser;

p.addRequired('Clip');
p.addRequired('Fs');
%Used to establish duration of peak finding filter
p.addRequired('MinFundFreq');
%Minimum separation between consequtive peaks
p.addRequired('MinSepSecs');

%Back up this many seconds to grab local background for subtraction
p.addParamValue('PeakDeltaTime', 0.1);
%Trim peaks less than this (clip is peak normalized)
p.addParamValue('MinPeak', 0.05); 
%Time to cut off the end to avoid running into next clip
p.addParamValue('PreMarginTime', 0.02); 
%If defined, cut off each clip when it drops to this fraction of the peak
%(helps with shorter bars, where the duration is small)
p.addParamValue('NoiseLimitCutoff', 0.0); 

p.addParamValue('PlotFlag', false); %Plot if true
p.addParamValue('DEBUG', false); %Debug data if true

p.parse(Clip, Fs, MinFundFreq, MinSepSecs, varargin{:});
Args=p.Results;

%Peak normalize the clip
Clip=Clip/max(Clip);

%Make mono if not
[s,ind]=min(size(Clip));
if(s~=1)
    Clip=Clip(:,1); %Want mono, not stero
end

%Make a time vector
t=(1:numel(Clip))/Fs; t=t';

%Do a running max based on the lowest anticipated fundamental freq
FiltLength = 2*floor(Fs/MinFundFreq)+1; %2 cycles of the fundimental (needs to be odd)
y=runningExtreme(Clip,FiltLength,'max');

%Filter the max history with a big moving average filter
MA_filt_length=5*FiltLength;
wts = ones(MA_filt_length,1)/MA_filt_length;
ysmoothed = conv(y,wts,'same');

%Find peaks in this
MinSepSamples=Fs*MinSepSecs;
[pks,locs]=findpeaks(ysmoothed,'MINPEAKDISTANCE',MinSepSamples);

%Trim peaks where points before the peak are too low
PeakDeltaSamp=floor(Args.PeakDeltaTime*Fs);
ValidPks=ones(numel(pks),1);
for i=1:numel(pks)
    if(pks(i)<Args.MinPeak)
        ValidPks(i)=false; %Remove peaks that are below threshold
    end
    
    %If not the first peak, then subtract previous baseline and remove low
    %peaks
    if((locs(i)-PeakDeltaSamp) > 0)
        if(pks(i)-ysmoothed(locs(i)-PeakDeltaSamp) < Args.MinPeak)
            ValidPks(i)=0;
        end
    end
end
ValidPks=logical(ValidPks);
pks=pks(ValidPks);locs=locs(ValidPks);

if(Args.PlotFlag)
    figure;
    plot(t,ysmoothed);
    xlabel('time [seconds]');
    ylabel('amplitude');
    hold on
    plot(locs/Fs,pks,'*');hold off;drawnow
    title('Sound Envelope');
end

PreMarginPoints=Fs*Args.PreMarginTime;
for i=1:numel(pks)
    if(i==numel(pks))
        EndPt=numel(Clip);
    else
        EndPt=locs(i+1)-PreMarginPoints;
    end
    
%     figure;
    %If NoiseLimitCutoff is specified, then cut each clip off when it drops
    %below Peak*NoiseLimitCutoff
    if(Args.NoiseLimitCutoff)
        local_ysmoothed=ysmoothed(locs(i):EndPt);
        below_noise_idx=find(local_ysmoothed/max(local_ysmoothed)<Args.NoiseLimitCutoff,1,'first');
        if(~isempty(below_noise_idx))
            below_noise_idx=below_noise_idx+locs(i);%Relative to overall clip
            EndPt=min(EndPt,below_noise_idx); %If signal drops below noise before end of sample
        end
    end
    
    
    x_local=Clip(locs(i):EndPt);
    Clips{i}=x_local;
    
end



end